__all__ = ['road']

import time


def cycle():
    string = '.'
    a = 0
    b = True
    while b:
        if a <= 15:
            for i in range(1, 65 + 1):
                print(f'{string * i:97}.{string * i:>97}')
                a += 1
                time.sleep(0.025)
                if a == 65:
                    for i in range(65, 0, -1):
                        print(f"{string * i:97}.{string * i:>97}")
                        time.sleep(0.025)
                        if i == 1:
                            b = False


def road(num):
    for i in range(1, num + 1):
        cycle()



from setuptools import setup

setup(
    name='my_road',
    version='2.0.0',
    description='long Road or not????',
    py_modules=['my_road'],
    author='k0ng999',
    author_email='baydar_14@mail.ru',
    long_description=open('README.md', encoding='utf-8').read(),
    long_description_content_type='text/markdown',
    license='MIT',
)
